@@ -1,9 +1,5 @@
-use v5.16;
-
 package Module::Release;
 
-=encoding utf8
-
 =head1 NAME
 
 Module::Release - Automate software releases
@@ -15,7 +11,7 @@ Module::Release - Automate software releases
 	my $release = Module::Release->new( %params );
 
 	# call methods to automate your release process
-	$release->check_vcs;
+	$release->check_cvs;
 	...
 
 =cut
@@ -24,8 +20,9 @@ use strict;
 
 use warnings;
 no warnings;
+use vars qw($VERSION);
 
-our $VERSION = '2.127_04';
+$VERSION = '2.06';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -80,10 +77,18 @@ Use this value as the perl interpreter, otherwise use the value in C<$^X>.
 
 Do you want debugging output? Set this to a true value
 
+=item SF_PASS
+
+Your SourceForge password. If you don't set this and you want to
+upload to SourceForge, you should be prompted for it. Failing that,
+the module tries to upload anonymously but cannot claim the file for
+you.
+
 =item CPAN_PASS
 
 Your CPAN password. If you don't set this and you want to upload to
-PAUSE, you should be prompted for it.
+PAUSE, you should be prompted for it. Failing that, the module tries
+to upload anonymously but cannot claim the file for you.
 
 =back
 
@@ -95,23 +100,12 @@ C<ConfigReader::Simple> to get these values:
 
 =over 4
 
-=item cpan_user
+=item release_subclass (DEPRECATED)
 
-Your PAUSE user id.
-
-=item cpan_pass
-
-Your PAUSE password, but don't use this. Put it in the environment
-variable.
-
-=item http_proxy
-
-=item https_proxy
-
-=item ignore_prereqs
-
-A whitespace separated list of modules for C<Test::Prereq> to ignore.
-But, don't use C<Test::Prereq>. It was not a good idea.
+The subclass of C<Module::Release> that you want to use. This allows
+you to specify the subclass via a F<.releaserc> file; otherwise you
+wouldn't be able to use the C<release> script because the
+C<Module::Release> class name is hard-coded there.
 
 =item makefile_PL
 
@@ -119,20 +113,27 @@ The name of the file to run as F<Makefile.PL>.  The default is
 C<"Makefile.PL">, but you can set it to C<"Build.PL"> to use a
 C<Module::Build>-based system.
 
-If this is set to C<"Build.PL">, this his will also cause
-C<Module::Build::Prereqs> to use C<Test::Prereqs::Build> instead of
-C<Test::Prereqs>.
-
 =item makefile
 
 The name of the file created by C<makefile_PL> above.  The default is
 C<"Makefile">, but you can set it to C<"Build"> for
 C<Module::Build>-based systems.
 
-=item module_name
+=item cpan_user
 
-C<release> tries to guess the module name from the distro name, but if
-you don't like that, set the module name in the config file.
+Your PAUSE user id.
+
+=item sf_user
+
+Your SourceForge account (i.e. login) name.
+
+=item passive_ftp
+
+Set this to a true value to enable passive FTP.
+
+=item ignore_prereqs
+
+A whitespace separated list of modules for C<Test::Prereq> to ignore.
 
 =back
 
@@ -144,18 +145,39 @@ If you don't like what any of these methods do, override them in a subclass.
 
 =item new()
 
-Create the C<Module::Release> object. It reads the configuration
-and initializes everything.
+Create the bare bones C<Module::Release> object so you can read the
+configuration file. If you can read the configuration file, check for
+the C<release_subclass> directive. If the C<release_subclass> is there,
+C<new> calls the subclass's C<new> and returns the result. Otehrwise,
+this C<new> calls C<init> to set up the object.
+
+If you make a subclass, you're responsible for everything, including
+reading the configuration and adding it to your object.
 
 =cut
 
-sub new {
+sub new
+	{
 	my( $class, %params ) = @_;
 
 	my $self = bless {}, $class;
 
+	# NOTE: I have to read the configuration to see if I should
+	# call the subclass, but I haven't called init yet.
+	# Don't set up anything in _read_configuration!
 	my $config = $self->_read_configuration;
 
+	if( $config->release_subclass )
+		{
+		$self->_warn( "Use of release_subclass is deprecated" );
+		$self->_die( "release_subclass is the same class! Don't do that!" )
+			if $config->release_subclass eq $class;
+		my $subclass_self = $self->_handle_subclass(
+			$config->release_subclass, %params );
+
+		return $subclass_self;
+		}
+
 	$self->init( $config, %params );
 
 	return $self;
@@ -175,7 +197,8 @@ configuration values.
 
 =cut
 
-sub init {
+sub init
+	{
 	my( $self, $config, %params ) = @_;
 
 	$self->_set_defaults( %params );
@@ -190,7 +213,8 @@ sub init {
 
 sub _select_config_file_name { -e ".releaserc" ? ".releaserc" : "releaserc" }
 
-sub _set_defaults {
+sub _set_defaults
+	{
 	require Config;
 	require IO::Null;
 
@@ -204,18 +228,18 @@ sub _set_defaults {
 			debug          => $ENV{RELEASE_DEBUG} || 0,
 			local_file     => undef,
 			remote_file    => undef,
-			input_fh       => *STDIN{IO},
 			output_fh      => *STDOUT{IO},
 			debug_fh       => *STDERR{IO},
 			null_fh        => IO::Null->new(),
 			quiet          => 0,
 			devnull        => File::Spec->devnull,
 			ignore_prereqs => '',
-			module_name    => undef,
+
 			%params,
 		   };
 
-	foreach my $key ( keys %$defaults ) {
+	foreach my $key ( keys %$defaults )
+		{
 		$self->{$key} = $defaults->{$key};
 		}
 
@@ -226,7 +250,8 @@ sub _set_defaults {
 	# programmatic interface to Makemaker, and I don't want to
 	# treat Makemaker and Module::Build differently. I'm stuck
 	# with a fancy shell script.
-	if( -e 'Build.PL' ) {
+	if( -e 'Build.PL' )
+		{
 		$self->{'make'}        = File::Spec->catfile(qw{. Build});
 		$self->{'Makefile.PL'} = 'Build.PL';
 		$self->{'Makefile'}    = '_build';
@@ -234,7 +259,8 @@ sub _set_defaults {
 	1;
 	}
 
-sub _read_configuration {
+sub _read_configuration
+	{
 	require ConfigReader::Simple;
 
 	# NOTE: I have to read the configuration to see if I should
@@ -253,21 +279,26 @@ sub _read_configuration {
 	$config;
 	}
 
-sub _process_configuration {
+sub _process_configuration
+	{
 	my $self = shift;
 
 	# Figure out options
 	$self->{cpan} = $self->config->cpan_user eq '<none>' ? 0 : 1;
 
+	$self->{passive_ftp} =
+		($self->config->passive_ftp && $self->config->passive_ftp =~ /^y(es)?/) ? 1 : 0;
+
+
 	{
 	my @pairs = (
 		[ qw(Makefile.PL makefile_PL) ],
 		[ qw(Makefile    makefile)    ],
 		[ qw(make        make)        ],
-		[ qw(module_name module_name) ],
 		);
 
-	foreach my $pair ( @pairs ) {
+	foreach my $pair ( @pairs )
+		{
 		my( $key, $config ) = @$pair;
 
 		$self->{$key} = $self->config->get($config)
@@ -275,27 +306,34 @@ sub _process_configuration {
 		}
 	}
 
+
 	my @required = qw(  );
 
 	my $ok = 1;
-	for( @required ) {
-		unless( length $self->config->$_() ) {
+	for( @required )
+		{
+		unless( length $self->config->$_() )
+			{
 			$ok = 0;
 			$self->_warn( "Missing configuration data: $_; Aborting!\n" );
 			}
 		}
 	$self->_die( "Missing configuration data" ) unless $ok;
 
-	if( $self->config->perls ) {
+
+	if( $self->config->perls )
+		{
 		my @paths = split /:/, $self->config->perls;
 
-		foreach my $path ( @paths ) {
+		foreach my $path ( @paths )
+			{
 			$self->add_a_perl( $path );
 			}
 		}
 	}
 
-sub _handle_subclass {
+sub _handle_subclass
+	{
 	my( $self, $subclass, %params ) = @_;
 
 
@@ -304,7 +342,8 @@ sub _handle_subclass {
 	# we haven't loaded, it might be in another file the user already
 	# loaded, or the user might have defined it inline inside
 	# the script. We'll try loading it if it fails can()
-	unless( eval { $subclass->can( 'new' ) } ) {
+	unless( eval { $subclass->can( 'new' ) } )
+		{
 		# I don't care if this fails because loading the file
 		# might not be the problem
 		eval { require File::Spec->catfile( split '::', $subclass ) . '.pm' };
@@ -336,12 +375,15 @@ Added in 1.21
 
 =cut
 
-sub load_mixin {
+sub load_mixin
+	{
 	my( $self, $module ) = @_;
 
 	return 1 if $self->mixin_loaded( $module );
 
-	{ local $^W = 0; eval "use $module" };
+	no warnings 'redefine';
+
+	eval "use $module";
 
 	$self->_die( "Could not load [$module]! $@" ) if $@;
 
@@ -368,7 +410,7 @@ sub mixin_loaded { exists $Loaded_mixins{ $_[1] } }
 
 =back
 
-=head2 Methods for configuration and settings
+=head2 Methods for configuation and settings
 
 =over 4
 
@@ -381,6 +423,63 @@ object;
 
 sub config { $_[0]->{config} }
 
+=item get_web_user_agent
+
+Get a web user agent that follows the LWP::UserAgent API. The first time
+you call this it also sets up the web client by calling C<setup_web_client>.
+
+=cut
+
+sub get_web_user_agent { $_[0]->{web_user_agent} || $_[0]->setup_web_user_agent }
+
+=item setup_web_user_agent( ARGS )
+
+Create a web user agent and store it in the object. Get a reference to it
+by saving the result or calling C<get_web_user_agent>. If you call this
+method again, it replaces the internal web user agent (and anything you've
+done to it since you first set it up). It passes any arguments to the
+constructor of the user agent class.
+
+It calls C<web_user_agent_name> to set the initial agent name, and sets
+up an empty, in-memory cookie jar.
+
+=cut
+
+sub setup_web_user_agent
+	{
+	my $self = shift;
+
+	my $class = $self->web_user_agent_class;
+	my $rc = eval { eval "require $class" };
+	unless( $rc ) { $self->_die( "Could not load $class: $@" ) };
+
+	my $ua = $self->web_user_agent_class->new(
+		agent => $self->web_user_agent_name,
+		@_
+		);
+
+	$ua->cookie_jar( {} );
+
+	$self->{web_user_agent} = $ua;
+	}
+
+=item web_user_agent_class
+
+The package name to use to build a web user agent object.
+
+=cut
+
+sub web_user_agent_class { 'LWP::UserAgent' }
+
+=item web_user_agent_name
+
+The user agent name to use with web requests. Let's just call that
+C<Mozilla> for now.
+
+=cut
+
+sub web_user_agent_name { 'Mozilla' }
+
 =item local_file( FILENAME )
 
 Returns or sets the name of the local distribution file. You can use
@@ -388,7 +487,8 @@ the literal argument C<undef> to clear the value.
 
 =cut
 
-sub local_file {
+sub local_file
+	{
 	$_[0]->{local_file} = $_[1] if @_ > 1;
 
 	$_[0]->{local_file};
@@ -401,7 +501,8 @@ literal argument C<undef> to clear the value.
 
 =cut
 
-sub remote_file {
+sub remote_file
+	{
 	$_[0]->{remote_file} = $_[1] if @_ > 1;
 
 	$_[0]->{remote_file};
@@ -448,8 +549,6 @@ sub _looks_like_perl {
 
 	# resolve a path, especially on Windows, like
 	# C:\STRAWB~1\perl\bin\perl.exe
-	return 1 if $path =~ /\bperl.exe\z/;
-
 	my $version = `$path -e "print \$\]" 2>&1`;
 
 	$version =~ m/^\d+\.[\d_]+$/ ? $version : ();
@@ -476,26 +575,7 @@ Added in 1.21.
 
 =cut
 
-sub perls {
-    my $self = shift;
-
-    my @perls = keys %{$self->{perls}};
-	$self->_debug( "perls at the start [@perls]" );
-
-    # Sort them
-    @perls =
-	map  { $_->[0] }
-	sort { $a->[2] <=> $b->[2] || $a->[3] <=> $b->[3] || $a->[0] cmp $b->[0] }
-	map  { [ $_->[0], ( $_->[1] =~ m/(perl5\.(?|([0-9]{3})_?([0-9]{2})|([0-9]{1,2})\.([0-9]+)))/) ] }
-	map  { [ $_, (m{.*/(.*)}) ] }
-	grep { -x $_ }
-	@perls;
-
-	$self->_debug( "perls after filtering [@perls]" );
-	$self->_debug( "Testing with " . @perls . " perls" );
-
-    return @perls;
-    }
+sub perls { keys %{ $_[0]->{perls} } }
 
 =item add_a_perl( PATH )
 
@@ -509,16 +589,20 @@ Added in 1.21.
 
 =cut
 
-sub add_a_perl {
+sub add_a_perl
+	{
 	my( $self, $path ) = @_;
 
 	return 1 if exists $self->{perls}{$path};
 
-	unless( -x $path ) {
-		if( $path =~ m/[*?[]/ && $self->config->allow_glob_in_perls ) {
+	unless( -x $path )
+		{
+		if( $path =~ m/[*?[]/ && $self->config->allow_glob_in_perls )
+			{
 			$self->add_a_perl( $_ ) for glob $path;
 			}
-		else {
+		else
+			{
 			$self->_warn( "$path is not executable" );
 			}
 		return;
@@ -526,7 +610,8 @@ sub add_a_perl {
 
 	my $version = $self->_looks_like_perl( $path );
 
-	unless( $version ) {
+	unless( $version )
+		{
 		$self->_warn( "$path does not appear to be perl!" );
 		return;
 		}
@@ -542,7 +627,8 @@ Added in 1.21.
 
 =cut
 
-sub remove_a_perl {
+sub remove_a_perl
+	{
 	my( $self, $path ) = @_;
 
 	return delete $self->{perls}{$path}
@@ -556,7 +642,8 @@ Added in 1.21.
 
 =cut
 
-sub reset_perls {
+sub reset_perls
+	{
 	my $self = shift;
 
 	$self->{perls} = {};
@@ -565,16 +652,6 @@ sub reset_perls {
 	}
 
 
-=item input_fh
-
-Return the value of input_fh.
-
-=cut
-
-sub input_fh {
-    return $_[0]->{input_fh};
-}
-
 =item output_fh
 
 If quiet is off, return the value of output_fh. If output_fh is not
@@ -598,14 +675,11 @@ return whatever they like.
 
 =cut
 
-sub null_fh  {
-	require IO::Null;
-	$_[0]->{null_fh} //= IO::Null->new;
-	}
+sub null_fh  { $_[0]->{null_fh} }
 
 =item quiet
 
-Get the value of quiet mode (true or false).
+Get the value of queit mode (true or false).
 
 =item turn_quiet_on
 
@@ -647,12 +721,11 @@ sub turn_debug_off { $_[0]->{debug} = 0 }
 sub debug          { $_[0]->{debug} }
 
 sub debug_fh  {
-		if( $_[0]->debug ) {
-			$_[0]->{debug_fh} || *STDERR{IO}
-			}
-		else {
-			$_[0]->null_fh
-			}
+	$_[0]->debug
+		?
+	( $_[0]->{debug_fh} || *STDERR{IO} )
+		:
+	$_[0]->null_fh
 	}
 
 =back
@@ -667,11 +740,13 @@ Run `make realclean`
 
 =cut
 
-sub clean {
+sub clean
+	{
 	my $self = shift;
 	$self->_print( "Cleaning directory... " );
 
-	unless( -e $self->{Makefile} ) {
+	unless( -e $self->{Makefile} )
+		{
 		$self->_print( " no $self->{Makefile}---skipping\n" );
 		return;
 		}
@@ -687,11 +762,13 @@ Run `make distclean`
 
 =cut
 
-sub distclean {
+sub distclean
+	{
 	my $self = shift;
 	$self->_print( "Cleaning directory... " );
 
-	unless( -e $self->{Makefile} ) {
+	unless( -e $self->{Makefile} )
+		{
 		$self->_print( " no $self->{Makefile}---skipping\n" );
 		return;
 		}
@@ -711,11 +788,13 @@ C<Makefile.PL>.
 
 =cut
 
-sub build_makefile {
+sub build_makefile
+	{
 	my $self = shift;
 	$self->_print( "Recreating make file... " );
 
-	unless( -e $self->{'Makefile.PL'} ) {
+	unless( -e $self->{'Makefile.PL'} )
+		{
 		$self->_print( " no $self->{'Makefile.PL'}---skipping\n" );
 		return;
 		}
@@ -731,7 +810,8 @@ Run a plain old `make`.
 
 =cut
 
-sub make {
+sub make
+	{
 	my $self = shift;
 	$self->_print( "Running make... " );
 
@@ -752,11 +832,13 @@ Run `make test`. If any tests fail, it dies.
 
 =cut
 
-sub test {
+sub test
+	{
 	my $self = shift;
 	$self->_print( "Checking make test... " );
 
-	unless( -e $self->{'Makefile'} ) {
+	unless( -e $self->{'Makefile'} )
+		{
 		$self->_print( " no $self->{'Makefile'}---skipping\n" );
 		return;
 		}
@@ -796,9 +878,10 @@ name if not set on the command line.
 
 =cut
 
-sub dist {
+sub dist
+	{
 	my $self = shift;
-	$self->_print( "Making dist...\n" );
+	$self->_print( "Making dist... " );
 
 	$self->build_makefile;
 
@@ -806,7 +889,8 @@ sub dist {
 	$self->_debug( "messages are [$messages]\n" );
 
 	# If the distro isn't already set, try to guess it
-	unless( $self->local_file ) {
+	unless( $self->local_file )
+		{
 		$self->_debug( ", guessing local distribution name\n" );
 		my( $guess ) = $messages =~ /(?:\s|')(\S+\.tar)/;
 		$self->_debug( "guessed [$guess]\n" );
@@ -823,7 +907,7 @@ sub dist {
 	$self->_die( "Local file '$self->{local_file}' does not exist\n" )
 		unless -f $self->local_file;
 
-	$self->_print( "Done making dist\n" );
+	$self->_print( "done\n" );
 	}
 
 =item disttest
@@ -832,12 +916,14 @@ Run `make disttest`. If the tests fail, it dies.
 
 =cut
 
-sub disttest {
+sub disttest
+	{
 	my $self = shift;
 
 	$self->_print( "Checking make disttest... " );
 
-	unless( -e $self->{'Makefile'} ) {
+	unless( -e $self->{'Makefile'} )
+		{
 		$self->_print( " no $self->{'Makefile'}---skipping\n" );
 		return;
 		}
@@ -858,7 +944,8 @@ give a warning.
 
 =cut
 
-sub dist_test {
+sub dist_test
+	{
 	$_[0]->_warn( "dist_test is deprecated. Use disttest instead." );
 
 	goto &disttest;
@@ -870,89 +957,58 @@ Return the distribution version ( set in dist() )
 
 =cut
 
-sub _parse_version {
-	my( $self ) = @_;
-	no warnings 'uninitialized';
+sub dist_version
+	{
+	my $self = shift;
 
 	$self->_die( "Can't get dist_version! It's not set (did you run dist first?)" )
 		unless defined $self->remote_file;
 
-	my( $version_str, $vee, $version, $dev ) = $self->remote_file
-		=~ / ( (v?) ([\d.]+) (?: _ (\d+) )? ) (?:\. (?: tar \. gz | zip ) )? $/xi
-			or return { components => [], string => '', multipart => 0 };
+	no warnings 'uninitialized';
+	my ($version_str, $vee, $version) = $self->remote_file
+		=~ / ( (v?) ([\d_.]+) ) (?:\. tar \. gz)? $/xi
+			or return '';
 
 	my @components = split /[.]/, $version;
-	my $count      = @components;
-
-	my $multipart  = length($vee) || ($count > 2);
-
-	my $hash = {
-		components => \@components,
-		count      => $count,
-		string     => $version_str,
-		vee        => lc $vee,
-		version    => $version,
-		v_version  => lc($vee) . $version,
-		dev        => $dev,
-		multipart  => $multipart,
-		};
-
-	$self->_debug( Dumper( $self->remote_file, $hash ) ); use Data::Dumper;
-
-	return $hash;
-	}
-
-sub dist_version {
-	my( $self ) = @_;
-
-	my $v = $self->_parse_version;
-
-	if( $v->{multipart} ) {
-		$self->_debug( "Choosing multipart version" );
-		# This is a multi-part version
+	if ($vee || @components > 2) # This is a multi-part version
+		{
 		# We assume that version.pm is available if multi-part
 		# versions are in use.
-		eval {
+		eval
+			{
 			require version;
 			}
-		or do { # Fall back to using $version_str verbatim
+		or do
+		    	{ # Fall back to using $version_str verbatim
 			warn $@;
-			return $v->{version_str};
+			return $version_str;
 			};
 
 		# There are pre- and post-0.77 versions of version.pm.
 		# The former are deprecated, but I assume we must
 		# gracefully use what we have available.
-		eval {
-			my $string = $v->{v_version};
-			$v->{version} = version->VERSION >= 0.77 ?
-				version->parse ($string)->normal : # latest and best
-				''.version->new($string)         ; # legacy
+		eval
+			{
+			$version = version->VERSION >= 0.77?
+				version->parse (lc($vee) . $version)->normal : # latest and best
+				''.version->new(lc($vee) . $version)         ; # legacy
 			1;
 			}
 		or
-			$self->_die( "Couldn't parse version '$v->{string}' from '".
+			$self->_die( "Couldn't parse version '$version_str' from '".
 				$self->remote_file. "': $@");
 
-		return $v->{version};
-		}
-	elsif( $v->{count} == 1 ) {
-		$self->_debug( "Choosing single component version" );
-		# some versions might be a single number, such as those
-		# that use dates as integers with no dot.
-		return $v->{components}[0];
-		}
-	elsif( $v->{string} =~ /(\d+) \. (\d+)(_\d+)? $/x ) {
-		$self->_debug( "Choosing major.minor_dev? version" );
-		# Else, use the older implementation for backward-compatibility
-		# Note the lack of an initial ^ matcher is deliberate.
-		my( $major, $minor, $dev ) = ( $1, $2, $3 );
-		return $self->dist_version_format( $major, $minor, $dev );
-		}
-	else {
-		$self->_debug( "Unhandled version" );
-		return '';
+		return $version;
 		}
+
+
+	# Else, use the older implementation for backward-compatibility
+	# Note the lack of an initial ^ matcher is deliberate.
+
+	my( $major, $minor, $dev ) =
+		$version_str =~ /(\d+) \. (\d+)(_\d+)? $/xg;
+
+	return $self->dist_version_format( $major, $minor, $dev );
 	}
 
 =item dist_version_format
@@ -963,33 +1019,13 @@ Return the distribution version ( set in dist() )
 
 =cut
 
-sub dist_version_format {
+sub dist_version_format
+	{
 	no warnings 'uninitialized';
 	my $self = shift;
 	my( $major, $minor, $dev ) = @_;
 
-	sprintf "%s.%s%s", $major, $minor, $dev;
-	}
-
-=item module_name
-
-Returns the module name. This either takes it from the config file
-or tries to guess it from the distro name.
-
-=cut
-
-sub module_name {
-	my $self = shift;
-	return $self->{module_name} if $self->{module_name};
-
-	my $name = $self->local_file;
-	$self->_debug( "Guessing name. Local file is  <$name>\n" );
-
-	$name =~ s/-\d.*//g;
-	$name =~ s/-/::/g;
-	$self->_debug( "Guessing name. Module name is  <$name>\n" );
-
-	$self->{module_name} = $name;
+	sprintf "%d.%02d%s", $major, $minor, $dev;
 	}
 
 =item check_manifest
@@ -1012,19 +1048,22 @@ to re-run your release script.
 # for that output type.
 #
 # returns the number of interesting things it found, but that's it.
-sub _check_output_lines {
+sub _check_output_lines
+	{
 	my $self = shift;
 	my( $message_hash, $message ) = @_;
 
 	my %state;
-	foreach my $state ( keys %$message_hash ) {
+	foreach my $state ( keys %$message_hash )
+		{
 		$state{$state} = [ $message =~ /^\Q$state\E\s+(.+)/gm ];
 		}
 
 	my $rule = "-" x 50;
 	my $count = 0;
 
-	foreach my $key ( sort keys %state ) {
+	foreach my $key ( sort keys %state )
+		{
 		my $list = $state{$key};
 		next unless @$list;
 
@@ -1034,10 +1073,12 @@ sub _check_output_lines {
 		$self->_print( "\n\t$message_hash->{$key}\n\t$rule\n\t@$list\n" );
 		}
 
+
 	return $count;
 	}
 
-sub check_manifest {
+sub check_manifest
+	{
 	my $self = shift;
 
 	$self->_print( "Checking state of MANIFEST... " );
@@ -1059,7 +1100,7 @@ sub check_manifest {
 
 =item manifest_name
 
-Return the name of the manifest file, probably F<MANIFEST>.
+Return the name of the manifes file, probably F<MANIFEST>.
 
 =item manifest
 
@@ -1081,7 +1122,8 @@ Return the filenames in the manifest file as a list.
 
 =cut
 
-sub files_in_manifest {
+sub files_in_manifest
+	{
 	my $self = shift;
 
 	require ExtUtils::Manifest;
@@ -1092,10 +1134,12 @@ sub files_in_manifest {
 	my $hash = do {
 		local $SIG{'__WARN__'} = sub {
 			my $message = shift;
-			if( $message =~ m/Debug: (.*)/ ) {
+			if( $message =~ m/Debug: (.*)/ )
+				{
 				$self->_debug( $1 );
 				}
-			else {
+			else
+				{
 				$self->_die( "files_in_manifest: could not open file\n" );
 				}
 			};
@@ -1127,17 +1171,20 @@ separate module.
 
 =cut
 
-sub check_vcs {
-	$_[0]->_die( "check_vcs must be implemented in a mixin class" );
+sub check_vcs
+	{
+	$_[0]->_die( "check_cvs must be implemented in a mixin class" );
 	}
 
 
-sub vcs_tag {
-	$_[0]->_die( "vcs_tag must be implemented in a mixin class" );
+sub vcs_tag
+	{
+	$_[0]->_die( "cvs_tag must be implemented in a mixin class" );
 	}
 
-sub make_vcs_tag {
-	$_[0]->_die( "make_vcs_tag must be implemented in a mixin class" );
+sub make_vcs_tag
+	{
+	$_[0]->_die( "make_cvs_tag must be implemented in a mixin class" );
 	}
 
 =item touch( FILES )
@@ -1151,14 +1198,17 @@ Returns the number of files which it successfully touched.
 
 =cut
 
-sub touch {
+sub touch
+	{
 	my( $self, @files ) = @_;
 
 	my $time = time;
 
 	my $count = 0;
-	foreach my $file ( @files ) {
-		unless( -f $file ) {
+	foreach my $file ( @files )
+		{
+		unless( -f $file )
+			{
 			$self->_warn( "$file is not a plain file" );
 			next;
 			}
@@ -1170,7 +1220,8 @@ sub touch {
 		utime( $time, $time, $file );
 
 		# check that it actually worked
-		unless( 2 == grep { $_ == $time } (stat $file)[8,9] ) {
+		unless( 2 == grep { $_ == $time } (stat $file)[8,9] )
+			{
 			$self->_warn( "$file did not set utimes." );
 			next;
 			}
@@ -1195,34 +1246,42 @@ sub touch_all_in_manifest { $_[0]->touch( $_[0]->files_in_manifest ) }
 
 =over 4
 
-=item should_upload_to_pause
-
-Should I upload to PAUSE? If C<cpan_user> and C<cpan_pass> are set,
-go for it.
-
-=cut
-
-sub should_upload_to_pause {
-	$_[0]->_debug( "Checking if I should upload\n" );
-	my $answer = !!( $_[0]->config->cpan_user && $_[0]->config->cpan_pass );
-	$_[0]->_debug( "The answer is [$answer]\n" );
-	$answer;
-	}
-
 =item check_for_passwords
 
 Get passwords for CPAN.
 
 =cut
 
-sub check_for_passwords {
-	if( my $pass = $_[0]->config->cpan_user && $_[0]->get_env_var( "CPAN_PASS" )  ) {
+sub check_for_passwords
+	{
+	if( my $pass = $_[0]->config->cpan_user && $_[0]->get_env_var( "CPAN_PASS" )  )
+		{
 		$_[0]->config->set( 'cpan_pass', $pass );
 		}
 
 	$_[0]->_debug( "CPAN pass is " . $_[0]->config->cpan_pass . "\n" );
 	}
 
+
+
+=item get_readme()
+
+Read and parse the F<README> file.  This is pretty specific, so
+you may well want to overload it.
+
+=cut
+
+sub get_readme
+	{
+	open my $fh, '<README' or return '';
+	my $data = do {
+		local $/;
+		<$fh>;
+		};
+
+	return $data;
+	}
+
 =item get_changes()
 
 Read and parse the F<Changes> file.  This is pretty specific, so
@@ -1230,12 +1289,14 @@ you may well want to overload it.
 
 =cut
 
-sub get_changes {
-	open my $fh, '<:encoding(UTF-8)', 'Changes' or return '';
+sub get_changes
+	{
+	open my $fh, '<', 'Changes' or return '';
 
 	my $data = <$fh>;  # get first line
 
-	while( <$fh> ) {
+	while( <$fh> )
+		{
 		last if /^\S/;
 		$data .= $_;
 		}
@@ -1243,36 +1304,6 @@ sub get_changes {
 	return $data;
 	}
 
-=item show_recent_contributors()
-
-Show recent contributors before creating/extending Changes.
-
-This output relies upon the method C<get_recent_contributors()> having been
-implemented in the relevant mixin for your version control system.
-
-=cut
-
-sub show_recent_contributors {
-	my $self = shift;
-	return unless $self->can( 'get_recent_contributors' );
-	my @contributors = $self->get_recent_contributors;
-	$self->_print("Contributors since last release:\n") if @contributors;
-	$self->_print( "\t", $_, "\n" ) for @contributors;
-	}
-
-=item get_release_date()
-
-Return a string representing the current date and time (in UTC) in the
-L<CPAN::Changes::Spec> format so that it can be added directly to the
-Changes file.
-
-=cut
-
-sub get_release_date {
-	state $rc = require Time::Piece;
-	return Time::Piece->gmtime->datetime . 'Z';
-	}
-
 =item run
 
 Run a command in the shell.
@@ -1289,7 +1320,8 @@ sub _run_error_reset { $_[0]->{_run_error} = 0 }
 sub _run_error_set   { $_[0]->{_run_error} = 1 }
 sub run_error        { $_[0]->{_run_error}     }
 
-sub run {
+sub run
+	{
 	my( $self, $command ) = @_;
 
 	$self->_run_error_reset;
@@ -1297,7 +1329,7 @@ sub run {
 	$self->_debug( "$command\n" );
 	$self->_die( "Didn't get a command!" ) unless defined $command;
 
-	open my($fh), "-|", "$command" or $self->_die( "Could not open command [$command]: $!" );
+	open my($fh), "$command |" or $self->_die( "Could not open command [$command]: $!" );
 	$fh->autoflush;
 
 	my $output = '';
@@ -1306,7 +1338,8 @@ sub run {
 
 	my $readlen = $self->debug ? 1 : 256;
 
-	while( read $fh, $buffer, $readlen ) {
+	while( read $fh, $buffer, $readlen )
+		{
 		$output .= $_;
 		$self->_debug( $_, $buffer );
 		$output .= $buffer;
@@ -1314,7 +1347,8 @@ sub run {
 
 	$self->_debug( $self->_dashes, "\n" );
 
-	unless( close $fh ) {
+	unless( close $fh )
+		{
 		$self->_run_error_set;
 		$self->_warn(  "Command [$command] didn't close cleanly: $?" );
 		}
@@ -1328,7 +1362,8 @@ Get an environment variable or prompt for it
 
 =cut
 
-sub get_env_var {
+sub get_env_var
+	{
 	my ($self, $field) = @_;
 
 	# Check for an explicit argument passed
@@ -1339,17 +1374,7 @@ sub get_env_var {
 	return $pass if defined( $pass ) && length( $pass );
 
 	$self->_print( "$field is not set.  Enter it now: " );
-	if ($field eq 'CPAN_PASS') {
-		# don't echo passwords to the screen
-		require Term::ReadKey;
-		local $| = 1;
-		Term::ReadKey::ReadMode('noecho');
-		$pass = $self->_slurp;
-		Term::ReadKey::ReadMode('restore');
-	}
-	else {
-		$pass = $self->_slurp;
-	}
+	$pass = <>;
 	chomp $pass;
 
 	return $pass if defined( $pass ) && length( $pass );
@@ -1372,17 +1397,6 @@ output_fh to a null filehandle, output goes nowhere.
 
 sub _print { print { $_[0]->output_fh } @_[1..$#_] }
 
-=item _slurp
-
-Read a line from whatever is in input_fh and return it.
-
-=cut
-
-sub _slurp {
-    my $fh = $_[0]->input_fh;
-    return <$fh>;
-}
-
 =item _dashes()
 
 Use this for a string representing a line in the output. Since it's a
@@ -1398,17 +1412,8 @@ Send the LIST to whatever is in debug_fh, or to STDERR. If you aren't
 debugging, debug_fh should return a null filehandle.
 
 =cut
-use Carp qw(carp);
-sub _debug {
-	my $self = shift;
 
-	my $debug_fh = $self->debug_fh;
-
-	print { $debug_fh } @_;
-	}
-
-
-#eval { print { shift->debug_fh } @_; 1 } or carp "Failure in _debug: [@_] [$@]" }
+sub _debug { print { $_[0]->debug_fh } @_[1..$#_] }
 
 =item _die( LIST )
 
@@ -1444,9 +1449,9 @@ H.Merijn Brand has contributed many patches and features.
 
 =head1 SOURCE AVAILABILITY
 
-This source is in GitHub
+This source is in Github:
 
-	https://github.com/briandfoy/module-release
+	git://github.com/briandfoy/module-release.git
 
 =head1 AUTHOR
 
@@ -1454,10 +1459,10 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2021, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright (c) 2002-2011 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the Artistic License 2.0.
+it under the same terms as Perl itself.
 
 =cut
 
