@@ -2,11 +2,9 @@ package Module::Release::FTP;
 
 use strict;
 use warnings;
-use Exporter qw(import);
+use base qw(Exporter);
 use vars qw($VERSION);
 
-use Carp qw(croak);
-
 our @EXPORT = qw(
 	ftp_upload ftp_passive_on ftp_passive_off ftp_passive
 	ftp_class_name get_ftp_object
@@ -14,9 +12,7 @@ our @EXPORT = qw(
 	default_ftp_password default_ftp_upload_dir
 	);
 
-$VERSION = '2.123_04';
-
-=encoding utf8
+$VERSION = '2.06';
 
 =head1 NAME
 
@@ -24,9 +20,8 @@ Module::Release::FTP - Interact with an FTP server
 
 =head1 SYNOPSIS
 
-NOTE: PAUSE has turned off FTP uploads. Methods in this class
-will croak. If you want to make a private PAUSE with FTP, you
-can adapt this manual.
+The release script automatically loads this module when it's time
+to upload a file
 
 =head1 DESCRIPTION
 
@@ -48,8 +43,8 @@ module):
 
 =cut
 
-sub ftp_upload {
-	croak "PAUSE moved hosts and has turned off FTP uploads\n";
+sub ftp_upload
+	{
 	my $self = shift;
 
 	my %defaults = map { my $m = "default_ftp_$_"; $_, $self->$m() } qw(
@@ -124,12 +119,13 @@ sub ftp_class_name { 'Net::FTP' }
 
 =item get_ftp_object( HOSTNAME )
 
-Create and return the FTP object, based on the class name from
+Create and returnt the FTP object, based on the class name from
 C<ftp_class_name>. IT connects to HOSTNAME, but does not login.
 
 =cut
 
-sub get_ftp_object {
+sub get_ftp_object
+	{
 	my( $self, $site ) = @_;
 
 	my $class = $self->ftp_class_name;
@@ -194,9 +190,9 @@ L<Module::Release>
 
 =head1 SOURCE AVAILABILITY
 
-This source is in GitHub
+This source is in Github:
 
-	https://github.com/briandfoy/module-release
+	git://github.com/briandfoy/module-release.git
 
 =head1 AUTHOR
 
@@ -204,10 +200,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2017, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright (c) 2007-2011, brian d foy, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
