@@ -1,16 +1,13 @@
-use v5.16;
-
 package Module::Release::Kwalitee;
 
 use strict;
 use warnings;
-use Exporter qw(import);
+use base qw(Exporter);
+use vars qw($VERSION);
 
 our @EXPORT = qw(check_kwalitee cpants_lint cpants_pass_regex );
 
-our $VERSION = '2.127_04';
-
-=encoding utf8
+$VERSION = '2.06';
 
 =head1 NAME
 
@@ -36,10 +33,8 @@ It looks in local_name to get the name of the distribution file.
 
 sub check_kwalitee
 	{
-	my $cpants_analyse = "Module::CPANTS::Analyse";
-	my $cpants_lint    = "App::CPANTS::Lint";
-	eval "require $cpants_analyse; require $cpants_lint; 1" or
-		$_[0]->_die( "You need $cpants_analyse and $cpants_lint to check kwalitee" );
+	eval "require Module::CPANTS::Analyse; 1" or
+		$_[0]->_die( "You need Module::CPANTS::Analyse to check kwalitee" );
 
 	$_[0]->_print( "Checking kwalitee... " );
 
@@ -85,9 +80,9 @@ L<Module::Release>
 
 =head1 SOURCE AVAILABILITY
 
-This source is in GitHub
+This source is in Github:
 
-	https://github.com/briandfoy/module-release
+	git://github.com/briandfoy/module-release.git
 
 =head1 AUTHOR
 
@@ -95,10 +90,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2021, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright (c) 2007-2011, brian d foy, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
