@@ -1,16 +1,13 @@
-use v5.16;
-
 package Module::Release::MANIFEST;
 
 use strict;
 use warnings;
-use Exporter qw(import);
+use base qw(Exporter);
+use vars qw($VERSION);
 
 our @EXPORT = qw( check_MANIFEST );
 
-our $VERSION = '2.127_04';
-
-=encoding utf8
+$VERSION = '2.06';
 
 =head1 NAME
 
@@ -68,9 +65,9 @@ L<Module::Release>
 
 =head1 SOURCE AVAILABILITY
 
-This source is in GitHub
+This source is in Github:
 
-	https://github.com/briandfoy/module-release
+	git://github.com/briandfoy/module-release.git
 
 =head1 AUTHOR
 
@@ -78,10 +75,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2021, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright (c) 2009-2011, brian d foy, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
