@@ -1,18 +1,15 @@
-use v5.16;
-
 package Module::Release::SVN;
 
 use strict;
 use warnings;
-use Exporter qw(import);
+use base qw(Exporter);
+use vars qw($VERSION);
 
 use Carp;
 
 our @EXPORT = qw(check_vcs vcs_tag make_vcs_tag);
 
-our $VERSION = '2.127_04';
-
-=encoding utf8
+$VERSION = '2.06';
 
 =head1 NAME
 
@@ -50,12 +47,14 @@ Check the state of the SVN repository.
 
 =cut
 
-sub check_cvs {
+sub check_cvs
+	{
 	carp "check_cvs is deprecated in favor of check_vcs. Update your programs!";
 	&check_vcs;
 	}
 
-sub check_vcs {
+sub check_vcs
+	{
 	my $self = shift;
 
 	$self->_print( "Checking state of Subversion..." );
@@ -83,14 +82,16 @@ sub check_vcs {
 	my @svn_states = keys %message;
 
 	my %svn_state;
-	foreach my $state (@svn_states) {
+	foreach my $state (@svn_states)
+		{
 		$svn_state{$state} = [ $svn_update =~ /$state\s+(.*)/g ];
 		}
 
 	my $count;
 	my $question_count;
 
-	foreach my $key ( sort keys %svn_state ) {
+	foreach my $key ( sort keys %svn_state )
+		{
 		my $list = $svn_state{$key};
 		next unless @$list;
 
@@ -109,7 +110,7 @@ sub check_vcs {
 	if($question_count)
 		{
     	$self->_print "\nWARNING: Subversion is not up-to-date ($question_count files unknown); ",
-      "continue anyway? [Ny] " ;
+      "continue anwyay? [Ny] " ;
 		die "Exiting\n" unless <> =~ /^[yY]/;
 		}
 
@@ -129,12 +130,14 @@ Tag the release in Subversion.
 =cut
 
 
-sub cvs_tag {
+sub cvs_tag
+	{
 	carp "cvs_tag is deprecated in favor of vcs_tag. Update your programs!";
 	&check_vcs;
 	}
 
-sub vcs_tag {
+sub vcs_tag
+	{
 	require URI;
 
 	my $self = shift;
@@ -156,7 +159,8 @@ sub vcs_tag {
 	my $trunk_url = URI->new( $1 );
 
 	my @tag_url = $trunk_url->path_segments;
-	if(! grep /^trunk$/, @tag_url ) {
+	if(! grep /^trunk$/, @tag_url )
+		{
 		$self->_warn(
 			"\nWARNING: Current SVN URL:\n  $trunk_url\ndoes not contain a 'trunk' component\n",
 			"Aborting tagging.\n"
@@ -165,8 +169,10 @@ sub vcs_tag {
 		return;
 		}
 
-	foreach( @tag_url ) {
-		if($_ eq 'trunk') {
+	foreach( @tag_url )
+		{
+		if($_ eq 'trunk')
+			{
 			$_ = 'tags';
 			last;
 			}
@@ -179,10 +185,11 @@ sub vcs_tag {
 	# Make sure the top-level path exists
 	#
 	# Can't use $self->run() because of a bug where $fh isn't closed, which
-	# stops $? from being properly propagated.  Reported to brian d foy as
+	# stops $? from being properly propogated.  Reported to brian d foy as
 	# part of RT#6489
 	$self->run( "svn list $tag_url 2>&1" );
-	if( $? ) {
+	if( $? )
+		{
 		$self->_warn(
 			sprintf("\nWARNING:\n  svn list $tag_url\nfailed with non-zero exit status: %d\n", $? >> 8),
 			"Assuming tagging directory does not exist in repo.  Please create it.\n",
@@ -200,7 +207,8 @@ sub vcs_tag {
 
 	$self->run( "svn copy $trunk_url $tag_url" );
 
-	if ( $? ) {
+	if ( $? )
+		{
 		# already uploaded, and tagging is not (?) essential, so warn, don't die
 		$self->_warn(
 			sprintf(
@@ -225,12 +233,14 @@ different tagging scheme, or don't even call it.
 =cut
 
 
-sub make_cvs_tag {
+sub make_cvs_tag
+	{
 	carp "make_cvs_tag is deprecated in favor of make_vcs_tag. Update your programs!";
 	&make_vcs_tag;
 	}
 
-sub make_vcs_tag {
+sub make_vcs_tag
+	{
 	my $self = shift;
 	my( $major, $minor ) = $self->remote_file
 		=~ /(\d+) \. (\d+(?:_\d+)?) (?:\. tar \. gz)? $/xg;
@@ -238,8 +248,6 @@ sub make_vcs_tag {
 	return "RELEASE_${major}_${minor}";
 	}
 
-sub vcs_exit { 1 }
-
 =back
 
 =head1 SEE ALSO
@@ -248,9 +256,9 @@ L<Module::Release>
 
 =head1 SOURCE AVAILABILITY
 
-This source is in GitHub
+This source is in Github:
 
-	https://github.com/briandfoy/module-release
+	git://github.com/briandfoy/module-release.git
 
 =head1 AUTHOR
 
@@ -258,10 +266,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2021, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright (c) 2007-2011, brian d foy, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
